searchData={"content_type":"text/markdown","items":[{"doc":"ASCII chart generation.\n\n  Ported to Elixir from [https://github.com/kroitor/asciichart](https://github.com/kroitor/asciichart)","ref":"Asciichart.html","title":"Asciichart","type":"module"},{"doc":"Generates a chart for the specified list of numbers.\n\nOptionally, the following settings can be provided:\n  * :offset - the number of characters to set as the chart's offset (left)\n  * :height - adjusts the height of the chart\n  * :padding - one or more characters to use for the label's padding (left)\n  * :charset - a customizable character set\n  * :precision - number of fractional digits to keep for floating-point values","ref":"Asciichart.html#plot/2","title":"Asciichart.plot/2","type":"function"},{"doc":"iex> Asciichart.plot([1, 2, 3, 3, 2, 1])\n    {:ok, \"3.00 ┤ ╭─╮   \\n2.00 ┤╭╯ ╰╮  \\n1.00 ┼╯   ╰  \\n          \"}\n\n    # should render as\n\n    3.00 ┤ ╭─╮\n    2.00 ┤╭╯ ╰╮\n    1.00 ┼╯   ╰\n\n    iex> Asciichart.plot([1, 2, 6, 6, 2, 1], height: 2)\n    {:ok, \"6.00 ┤       \\n3.50 ┤ ╭─╮   \\n1.00 ┼─╯ ╰─  \\n          \"}\n\n    # should render as\n\n    6.00 ┤\n    3.50 ┤ ╭─╮\n    1.00 ┼─╯ ╰─\n\n    iex> Asciichart.plot([1, 2, 5, 5, 4, 3, 2, 100, 0], height: 3, offset: 10, padding: \"__\")\n    {:ok, \"    100.00    ┤      ╭╮  \\n    _50.00    ┤      ││  \\n    __0.00    ┼──────╯╰  \\n                    \"}\n\n    # should render as\n\n        100.00    ┤      ╭╮\n        _50.00    ┤      ││\n        __0.00    ┼──────╯╰\n\n    iex> Asciichart.plot([1, 2, 5, 5, 4, 3, 2, 100, 0], height: 3, offset: 10, padding: \"__\", precision: 3)\n    {:ok, \"   100.000     ┤      ╭╮  \\n   _50.000     ┤      ││  \\n   __0.000     ┼──────╯╰  \\n                    \"}\n\n    # should render as\n\n        100.000     ┤      ╭╮\n        _50.000     ┤      ││\n        __0.000     ┼──────╯╰\n\n\n    # Rendering of empty charts is not supported\n\n    iex> Asciichart.plot([])\n    {:error, \"No data\"}","ref":"Asciichart.html#plot/2-examples","title":"Examples - Asciichart.plot/2","type":"function"},{"doc":"Defines different character sets for plotting.","ref":"Asciichart.Charset.html","title":"Asciichart.Charset","type":"module"},{"doc":"","ref":"Asciichart.Charset.html#round/0","title":"Asciichart.Charset.round/0","type":"function"},{"doc":"","ref":"Asciichart.Charset.html#single_char/1","title":"Asciichart.Charset.single_char/1","type":"function"},{"doc":"","ref":"Asciichart.Charset.html#square/0","title":"Asciichart.Charset.square/0","type":"function"},{"doc":"# asciichart\n\n[![Hex version badge](https://img.shields.io/hexpm/v/asciichart.svg)](https://hex.pm/packages/asciichart) [![codecov](https://codecov.io/gh/sndnv/asciichart/graph/badge.svg?token=EVAYGZRRZB)](https://codecov.io/gh/sndnv/asciichart) [![license](https://img.shields.io/github/license/sndnv/asciichart.svg)]()\n\nTerminal ASCII line charts in Elixir with no dependencies.\n\n \n\nPorted to Elixir from [kroitor/asciichart](https://github.com/kroitor/asciichart)","ref":"readme.html","title":"asciichart","type":"extras"},{"doc":"Add `asciichart` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:asciichart, \"~>  \"}]\nend\n```","ref":"readme.html#install","title":"Install - asciichart","type":"extras"},{"doc":"```elixir\n{:ok, chart} = Asciichart.plot([1, 2, 3, 3, 2, 1])\nchart |> IO.puts()\n\n# should render as\n\n3.00 ┤ ╭─╮\n2.00 ┤╭╯ ╰╮\n1.00 ┼╯   ╰\n```","ref":"readme.html#usage","title":"Usage - asciichart","type":"extras"},{"doc":"One or more of the following settings can be provided:\n- `offset` - number of characters to set as the chart's (left) offset\n- `height` - adjusts the height of the chart\n- `padding` - one or more characters to use for the label's (left) padding\n- `charset` - a customizable character set. See `Asciichart.Charset`.\n- `precision` - number of fractional digits to keep for floating-point values\n\n```elixir\n{:ok, chart} = Asciichart.plot([1, 2, 5, 5, 4, 3, 2, 100, 0], height: 3, offset: 10, padding: \"__\")\nchart |> IO.puts()\n\n# should render as\n\n       ╭─> label\n    ------\n    100.00    ┼      ╭╮\n    _50.00    ┤      ││\n    __0.00    ┼──────╯╰\n    --\n---- ╰─> label padding\n ╰─> remaining offset (without the label)\n\n# Rendering of empty charts is not supported\n\nAsciichart.plot([])\n{:error, \"No data\"}\n```\nIf you want to change the character set, you can use a predefined one in `Asciichart.Charset` or create your own.\n```elixir\n{:ok, chart} = Asciichart.plot([1, 2, 5, 5, 4, 3, 2, 0], height: 5, charset: Asciichart.Charset.single_char(\"*\"))\nchart |> IO.puts()\n\n5.00 ┤ ***\n3.75 ┤ * **\n2.50 ┤ *  **\n1.25 ┤**   **\n0.00 **     *\n```","ref":"readme.html#options","title":"Options - asciichart","type":"extras"},{"doc":"We use [SemVer](http://semver.org/) for versioning.","ref":"readme.html#versioning","title":"Versioning - asciichart","type":"extras"},{"doc":"This project is licensed under the Apache License, Version 2.0 - see the [LICENSE](LICENSE) file for details\n\n> Copyright 2018 https://github.com/sndnv\n>\n> Licensed under the Apache License, Version 2.0 (the \"License\");\n> you may not use this file except in compliance with the License.\n> You may obtain a copy of the License at\n>\n> http://www.apache.org/licenses/LICENSE-2.0\n>\n> Unless required by applicable law or agreed to in writing, software\n> distributed under the License is distributed on an \"AS IS\" BASIS,\n> WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n> See the License for the specific language governing permissions and\n> limitations under the License.","ref":"readme.html#license","title":"License - asciichart","type":"extras"}]}